@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::JSONAPI;
-$Mojolicious::Plugin::JSONAPI::VERSION = '0.2';
+$Mojolicious::Plugin::JSONAPI::VERSION = '0.3';
 use Mojo::Base 'Mojolicious::Plugin';
 
 use JSONAPI::Document;
@@ -35,20 +35,32 @@ sub create_route_helpers {
             my $resource_singular = $resource->singular;
             my $resource_plural   = $resource->plural;
 
-            my $base_path  = $namespace ? "/$namespace/$resource_plural" : "/$resource_plural";
+            my $action_singular = $resource->singular;
+            my $action_plural   = $resource->plural;
+            $_ =~ s/-/_/g for ( $action_singular, $action_plural );
+
+            my $base_path =
+              $namespace ? "/$namespace/$resource_plural" : "/$resource_plural";
             my $controller = $spec->{controller} || "api-$resource_plural";
 
-            my $r = $app->routes->under($base_path)->to( controller => $controller );
-            $r->get('/')->to( action => "fetch_${resource_plural}" );
-            $r->post('/')->to( action => "post_${resource_singular}" );
+            my $r =
+              $app->routes->under($base_path)->to( controller => $controller );
+            $r->get('/')->to( action => "fetch_${action_plural}" );
+            $r->post('/')->to( action => "post_${action_singular}" );
             foreach my $method (qw/get patch delete/) {
-                $r->$method("/:${resource_singular}_id")->to( action => "${method}_${resource_singular}" );
+                $r->$method("/:${action_singular}_id")
+                  ->to( action => "${method}_${action_singular}" );
             }
 
             foreach my $relationship ( @{ $spec->{relationships} } ) {
-                my $path = "/:${resource_singular}_id/relationships/${relationship}";
+                my $path =
+                  "/:${action_singular}_id/relationships/${relationship}";
+                my $relationship_action = $relationship;
+                $relationship_action =~ s/-/_/g;
                 foreach my $method (qw/get post patch delete/) {
-                    $r->$method($path)->to( action => "${method}_related_${relationship}" );
+                    $r->$method($path)
+                      ->to(
+                        action => "${method}_related_${relationship_action}" );
                 }
             }
         }
@@ -93,7 +105,7 @@ sub create_error_helpers {
                 $errors = [
                     {
                         status => $status || 500,
-                        title  => 'Error processing request',
+                        title => 'Error processing request',
                     }
                 ];
             }
@@ -122,7 +134,7 @@ Mojolicious::Plugin::JSONAPI - Mojolicious Plugin for building JSON API complian
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 SYNOPSIS
 
@@ -137,7 +149,7 @@ version 0.2
 
         $self->resource_routes({
             resource => 'post',
-            relationships => ['author', 'comments'],
+            relationships => ['author', 'comments', 'email-templates'],
         });
 
         # Now the following routes are available:
@@ -158,6 +170,11 @@ version 0.2
         # PATCH '/api/posts/:post_id/relationships/comments' -> to('api-posts#patch_related_comments')
         # DELETE '/api/posts/:post_id/relationships/comments' -> to('api-posts#delete_related_comments')
 
+        # GET '/api/posts/:post_id/relationships/email-templates' -> to('api-posts#get_related_email_templates')
+        # POST '/api/posts/:post_id/relationships/email-templates' -> to('api-posts#post_related_email_templates')
+        # PATCH '/api/posts/:post_id/relationships/email-templates' -> to('api-posts#patch_related_email_templates')
+        # DELETE '/api/posts/:post_id/relationships/email-templates' -> to('api-posts#delete_related_email_templates')
+
         # You can use the following helpers too:
 
         $self->resource_document($dbic_row, $options);
@@ -202,10 +219,11 @@ C<resource> should be a singular noun, which will be turned into it's pluralised
 
 Specifying C<relationships> will create additional routes that fall under the resource.
 
-Routes will point to controller actions, the names of which follow the pattern C<{http_method}_{resource}>.
+Routes will point to controller actions, the names of which follow the pattern C<{http_method}_{resource}>, with
+dashes replaced with underscores (i.e. 'email-templates' -> 'email_templates').
 
 B<NOTE>: Your relationships should be in the correct form (singular/plural) based on the relationship in your
-schema management system. For example, if you have a resource called 'post' and it has many comments, make
+schema management system. For example, if you have a resource called 'post' and it has many 'comments', make
 sure comments is passed in as a plural noun.
 
 =head2 render_error(I<Str> $status, I<ArrayRef> $errors, I<HashRef> $data. I<HashRef> $meta)
